# My New Chert Site

This README, along with the directory structure around it, was
generated by Chert, a sparky little static site generator.

View the current state of the site by running using your terminal to
run `chert serve` in the same directory as this file, then visiting
`http://localhost:8080` in your browser. There are a few more steps
for the optimal Chert setup. You can start checking them off by
opening up TODO.md alongside this file.

As for the rest of the new contents:

  * Entries are Markdown files with YAML headers living in the
    `entries` directory
  * The `theme` directory has all of the HTML templates, JavaScript,
    CSS, and image assets that are not part of the content of the
    site. Any formatting changes not achievable in Markdown should be
    made to the theme.
  * Uploads are any media and files that aren't entries or part of the
    theme, but should still be uploaded to the production site. Those
    go in the `uploads` directory.
  * The site is generated into the `site` directory that will be
    created on the first `chert render`, `chert serve`, or `chert
    publish` commands. Browse this directory to see the exact
    structure that will be replicated on the remote server using
    rsync.
  * `config.yaml` controls the details of the site, such as the title
    and tagline, as well as the production environment, such as the
    remote destination host, user, and path.
  * `custom.py` gives you hooks into the Chert site generation.

If you encounter any trouble, [please create a new issue][chert_issues]!
Enjoy your new Chert site!

Unless otherwise specified, all non-code content copyright 2015
Authors [CC-BY-SA][cc_by_sa]. All code is BSD licensed by default, see
LICENSE for more details.

[chert_issues]: https://github.com/mahmoud/chert/issues
[cc_by_sa]: https://creativecommons.org/licenses/by-sa/4.0/
